%
%   BWorth.m   Selects appropriate blade worth curve for simulation and analysis
%              and passes back the integral worth at location z, rho(z) in %Dk/k
%
%   Inputs:
%     z = vector of blade positions (inches withdrawn)
%     boi = blade of interest (Blade 1 = 1, Blade 2 = 2, ... RegBlade = 5)
%     yr = year for blade worth evaluation (give full year, e.g 2013, 2014, etc.)
%     (see "case" description below for specific format for "yr" -- must be precise!)
%
%   Outputs:
%     rho = reactivity in %Dk/k of the BOI at location z (for evaluation year yr)
%   
%   Written by JRWhite, UMass-Lowell (last update: March 2018)
%

      function [rho,H] = bworth(z,boi,yr)
%
      check = 0;
      [zmin,imin] = min(z);  if zmin < 0, z(imin) = 0; end  % check on min z allowed
      switch yr
        case 'Jan2018'
%%   integral blade worth curves from Jan. 19, 2017 (M-5-8 core)
        HH =  [24.55 25.15 24.95 26.09 25.09]; % max blade heights(inches)
        H = HH(boi);                           % max blade ht for BOI
        [zmax,imax] = max(z);                  % check on max z allowed
        if zmax > H
          z(imax) = H;  disp('*** Warning  --  max z was modified ***');
        end  
        c = [8.049e-7  3.609e-5 -2.176e-3 1.358e-1 -2.835e+0 -3.894e-1;    % Blade 1
             5.823e-6 -2.978e-4  4.249e-3 9.335e-2 -2.614e+0 -3.299e-1;    % Blade 2
            -5.495e-6  3.787e-4 -7.310e-3 1.695e-1 -3.430e+0 -5.483e-1;    % Blade 3
             7.956e-6 -3.698e-4  5.643e-3 1.025e-1 -3.616e+0 -6.515e-1;    % Blade 4
             2.009e-6 -1.278e-4  2.305e-3 2.946e-3 -3.027e-1 -1.618e-2];   % RegBade (formal)
%            2.114e-6 -1.297e-4  2.275e-3 3.418e-3 -3.023e-1 -1.765e-2];   % RegBade (JRW re-eval)
        rhoz = @(z) c(boi,1)*z.^4 + c(boi,2)*z.^3 + c(boi,3)*z.^2 ...
                  + c(boi,4)*z + c(boi,5) + c(boi,6)*sin(2*pi*z/H);
        rho  = rhoz(z);
        check = 1;
        case 'Jan2017'
%%   integral blade worth curves from Jan. 25, 2017 (M-5-8 core)
        HH =  [24.55 25.15 24.95 26.09 25.09]; % max blade heights(inches)
        H = HH(boi);                           % max blade ht for BOI
        [zmax,imax] = max(z);                  % check on max z allowed
        if zmax > H
          z(imax) = H;  disp('*** Warning  --  max z was modified ***');
        end  
        c = [1.389e-6 -9.723e-5 2.132e-3 1.006e-1 -2.815e+0 -3.124e-1;    % Blade 1
             6.424e-6 -2.736e-4 2.970e-3 9.104e-2 -2.366e+0 -3.695e-1;    % Blade 2
             6.939e-6 -3.025e-4 3.854e-3 1.223e-1 -3.417e+0 -4.836e-1;    % Blade 3
             1.498e-5 -8.059e-4 1.341e-2 6.562e-2 -3.429e+0 -5.102e-1;    % Blade 4
             1.714e-6 -1.039e-4 1.806e-3 5.728e-3 -3.143e-1 -2.004e-2];   % RegBade
        rhoz = @(z) c(boi,1)*z.^4 + c(boi,2)*z.^3 + c(boi,3)*z.^2 ...
                  + c(boi,4)*z + c(boi,5) + c(boi,6)*sin(2*pi*z/H);
        rho  = rhoz(z);
        check = 1;
        case 'Jan2016'
%%   integral blade worth curves from Jan. 11, 2016 (after change to M-5-8 core)
        HH =  [24.55 25.15 24.95 26.09 25.09]; % max blade heights(inches)
        H = HH(boi);                           % max blade ht for BOI
        [zmax,imax] = max(z);                  % check on max z allowed
        if zmax > H
          z(imax) = H;  disp('*** Warning  --  max z was modified ***');
        end  
        c = [1.962e-6 -1.180e-4 2.241e-3 1.043e-1 -2.872e+0 -3.224e-1;    % Blade 1
             7.261e-6 -4.086e-4 7.039e-3 5.926e-2 -2.333e+0 -2.841e-1;    % Blade 2
             8.536e-6 -4.493e-4 7.695e-3 8.896e-2 -3.316e+0 -4.408e-1;    % Blade 3
             8.377e-6 -2.828e-4 6.700e-4 1.622e-1 -3.509e+0 -6.407e-1;    % Blade 4
             2.259e-6 -1.278e-4 2.168e-3 2.450e-3 -2.960e-1 -2.870e-2];   % RegBlade (1st try - less points)
%             1.927e-6 -9.056e-5 1.102e-3 1.120e-2 -2.975e-1 -4.186e-2];   % RegBlade (2nd try - more points)
%   Note: In a test on Jan. 19, 2016, the two different RegBlade curves did NOT
%         appear to have a significant effect. Although, not perfect as in some
%         of the early cases, the comparisons are reasonable (small positive bias).
%                                                               JRWhite 01/19/16
        rhoz = @(z) c(boi,1)*z.^4 + c(boi,2)*z.^3 + c(boi,3)*z.^2 ...
                  + c(boi,4)*z + c(boi,5) + c(boi,6)*sin(2*pi*z/H);
        rho  = rhoz(z);
        check = 1;
        case 'Nov2015'
%%   integral blade worth curves from Nov. 2015 (after replacement of Blade 3)
        HH =  [24.55 25.15 24.95 26.09 25.09]; % max blade heights(inches)
        H = HH(boi);                           % max blade ht for BOI
        [zmax,imax] = max(z);                  % check on max z allowed
        if zmax > H
          z(imax) = H;  disp('*** Warning  --  max z was modified ***');
        end  
        c = [1.532e-6 -9.101e-5 1.692e-3 9.895e-2 -2.657e+0 -3.036e-1;    % Blade 1
             1.014e-5 -4.379e-4 4.756e-3 8.531e-2 -2.217e+0 -3.589e-1;    % Blade 2
             9.391e-6 -4.591e-4 7.043e-3 1.041e-1 -3.456e+0 -4.593e-1;    % Blade 3
             1.139e-5 -6.506e-4 1.110e-2 9.125e-2 -3.631e+0 -4.635e-1;    % Blade 4
%             1.766e-6 -6.940e-5 5.000e-4 1.641e-2 -3.189e-1 -4.578e-2];   % RegBlade (from *.bwc from Drew in June 2015)
             2.608e-6 -1.301e-4 1.873e-3 6.793e-3 -3.167e-1 -3.919e-2];   % RegBlade (from extra Expt on 11/23/15)
        rhoz = @(z) c(boi,1)*z.^4 + c(boi,2)*z.^3 + c(boi,3)*z.^2 ...
                  + c(boi,4)*z + c(boi,5) + c(boi,6)*sin(2*pi*z/H);
        rho  = rhoz(z);
        check = 1;
        case 'June2015'
%%   integral blade worth curves from late June 2015 (after replacement of Blade 3)
        HH =  [24.55 25.15 24.95 26.09 25.09]; % max blade heights(inches)
        H = HH(boi);                           % max blade ht for BOI
        [zmax,imax] = max(z);                  % check on max z allowed
        if zmax > H
          z(imax) = H;  disp('*** Warning  --  max z was modified ***');
        end  
        c = [1.532e-6 -9.101e-5 1.692e-3 9.895e-2 -2.657e+0 -3.036e-1;    % Blade 1
             1.014e-5 -4.379e-4 4.756e-3 8.531e-2 -2.217e+0 -3.589e-1;    % Blade 2
             9.391e-6 -4.591e-4 7.043e-3 1.041e-1 -3.456e+0 -4.593e-1;    % Blade 3
%             4.816e-6 -2.512e-4 3.953e-3 1.313e-1 -3.689e+0 -4.599e-1;    % Blade 3 (from Lab#3 on 11/17/15)
             1.139e-5 -6.506e-4 1.110e-2 9.125e-2 -3.631e+0 -4.635e-1;    % Blade 4
             1.766e-6 -6.940e-5 5.000e-4 1.641e-2 -3.189e-1 -4.578e-2];   % RegBlade (from *.bwc from Drew in June 2015)
%             1.967e-6 -9.682e-5 1.322e-3 9.485e-3 -3.121e-1 -3.561e-2];   % RegBlade  (re-evaluation of June 2015 data in Nov 2015)
        rhoz = @(z) c(boi,1)*z.^4 + c(boi,2)*z.^3 + c(boi,3)*z.^2 ...
                  + c(boi,4)*z + c(boi,5) + c(boi,6)*sin(2*pi*z/H);
        rho  = rhoz(z);
        check = 1;
%%
%   Note: Reactor Lab #3 in Nov 2015 did not give a very good comparison of 
%         measured and computed P(t) and rho(t) values.  Also the Blade 3 worth
%         was measured to be 3.7 %Dk/k, which is a bit higher than measured 
%         back in June 2015 (got 3.5 %Dk/k in June).  I looked at the RegBlade  
%         worth curves and they seemed a little odd, so I did a re-evaluation 
%         using data from last June 2015.  I get a slightly different profile 
%         but the total worth is only a little different at 0.32 %Dk/k vs. 
%         0.33 %Dk/k in June.  I don't understand why or how things are 
%         different since we should be using the same base data?????
%     
%         In any case, the new re-evaluation only helped the comparisons a
%         little -- so, although the profiles are a little different, this is
%         not the main issue.  Could the RegBlade worth curve have changed?  I
%         requested a new RegBlade calibration, so we shall see...
%
%         Okay, we did a RegBlade calibration on 11/23/15 and, unfortunately, this
%         did not help.  The blade worth profile was a bit different, and it gave a
%         better comparison with the reactivity profiles, but it did not help the
%         P(t) simulations significantly (actually went in the wrong direction) since
%         now there seems to be a slight positive reactivtiy bias!!! 
%         
%         I also checked with Drew and there was no operation on the Monday before
%         the lab, so xenon decay is not the issue.  Thus, I have checked everything
%         and I can't account for why the inverse kinetics did not predict the same
%         worths as indicated with the RegBlade curve.  I will have to keep my eye on
%         this issue in future experiments...             
%
%         Note that a similar test on Jan. 4, 2016 showed similar behavior  --  the
%         Nov. 2015 worth curve is better and there is a slight reactivtiy bias.
%         Why???                                            (JRWhite, Jan. 6, 2016)
%
        case 2014
%%   integral blade worth curves for the Feb. 2014 evaluation
        HH =  [24.55 25.15 24.95 26.09 25.09]; % max blade heights(inches)
        H = HH(boi);                           % max blade ht for BOI
        [zmax,imax] = max(z);                  % check on max z allowed
        if zmax > H
          z(imax) = H;  disp('*** Warning  --  max z was modified ***');
        end  
        c = [2.620e-6 -1.642e-4 3.161e-3 8.829e-2 -2.592e+0 -2.723e-1;    % Blade 1
             6.660e-6 -3.591e-4 5.874e-3 5.796e-2 -2.114e+0 -2.709e-1;    % Blade 2
             7.286e-6 -3.291e-4 4.189e-3 1.195e-1 -3.283e+0 -4.567e-1;    % Blade 3
             1.288e-5 -6.586e-4 1.043e-2 7.570e-2 -3.316e+0 -5.603e-1;    % Blade 4
             2.302e-6 -1.159e-4 1.664e-3 8.078e-3 -3.162e-1 -3.496e-2];   % RegBlade
        rhoz = @(z) c(boi,1)*z.^4 + c(boi,2)*z.^3 + c(boi,3)*z.^2 ...
                  + c(boi,4)*z + c(boi,5) + c(boi,6)*sin(2*pi*z/H);
        rho  = rhoz(z);
        check = 1;
%      
        case 2013
%%   integral blade worth curves for the Feb. 2013 evaluation
        HH =  [24.55 25.15 24.95 26.09 25.09]; % max blade heights(inches)
        H = HH(boi);                           % max blade ht for BOI
        [zmax,imax] = max(z);                  % check on max z allowed
        if zmax > H
          z(imax) = H;  disp('*** Warning  --  max z was modified ***');
        end  
        c = [5.115e-6 -3.222e-4 6.323e-3 7.061e-2 -2.628e+0 -2.630e-1;    % Blade 1
             9.645e-6 -5.207e-4 8.613e-3 4.514e-2 -2.137e+0 -2.603e-1;    % Blade 2
             9.360e-6 -5.181e-4 8.776e-3 8.945e-2 -3.261e+0 -3.897e-1;    % Blade 3
             1.279e-5 -7.375e-4 1.323e-2 6.089e-2 -3.397e+0 -4.598e-1;    % Blade 4
             2.154e-6 -1.359e-4 2.526e-3 1.129e-3 -3.240e-1 -1.964e-2];   % RegBlade
        rhoz = @(z) c(boi,1)*z.^4 + c(boi,2)*z.^3 + c(boi,3)*z.^2 ...
                  + c(boi,4)*z + c(boi,5) + c(boi,6)*sin(2*pi*z/H);
        rho  = rhoz(z);
        check = 1;
%      
        case 2007
%      ***  This is a special case where only the RegBlade is considerwed  ***
%   integral blade worth curves for the Jan. 2007 evaluation (only RegBlade data)
        if boi ~= 5, disp('***  Warning -- data for BOI is NOT available  ***');  end
        H = 26;   
        [zmax,imax] = max(z);                  % check on max z allowed
        if zmax > H
          z(imax) = H;  disp('*** Warning  --  max z was modified ***');
        end  
        c1 = 6.5250e-3;  c2 = 2.7035e-3;     % curve fit from Jan. 2007
        c3 = -2.0533e-4;  c4 = 3.9070e-6;  c5 = -6.6337e-3;
        rhoz = @(z) c1*z + (c2/2)*z.^2 + (c3/3)*z.^3 + (c4/4)*z.^4 + ...
               (c5*H/(2*pi))*sin(2*pi*z/H);
        rho  = rhoz(z);
        check = 1;
      end
%
%   print error if no data for year requested
      if check == 0, disp('***  Warning -- data for year requested is NOT available  ***');  end
%
%   end of function