%
%   PKEQNS_RampB_FDBK.M  Point Kinetics Equations for linearly varying blade 
%                        movement, z(t), with temperature and xenon feedbacks
%
%   This function file is called by ode15s to solve the kinetics eqns. with 
%   feedbacks for the case of a linearly varying z(t),  time varying Tin(t), and a
%   constant neutron source, Q.  Note that the equations have been normalized so 
%   that the neutron amplitude represents power in watts, Tin is in oC, and Q is 
%   in neutrons/sec. 
%
%   rho0 is the initial reactivity 
%   rate is the blade speed in inches/sec
%   zloc contains start & end location for the blade of inteest BOI (inches out)
%   tT,Tint are pointwise values of the inlet temperature (oC) vs time (where linear 
%       interpolation is used for any t)
%   Tcr,Tfr are reference temperatures (oC) for use in the temperature feedback terms
%   cfac is the flux correction factor for the xenon model
%   boi,yr define the blade of interest and the year for the worth curves
%   opt_alfTf = option for choice of fuel temp coeff
%
%   Written by  J. R. White, UMass-Lowell  (March 2014)
%

      function xp = pkeqns_rampb_fdbk(t,x,rho0,Q,Be,Gt,B,lam,kappa,nu, ...
                    rate,zloc,tstrt,tT,Tint,Tcr,Tfr,cfac,mode,boi,yr,opt_alfTf)
%   assign usual variable names to the elements of the state vector (11 eqn model),
%   where P is in watts and the temperatures are in oC
      P = x(1); C = x(2:7);  Tf = x(8);  Tc = x(9);  I = x(10);  X = x(11);
%
      xp = zeros(length(x),1);               % initialize derivative of state
      Tin = interp1(tT,Tint,t,[],Tint(end)); % inlet temp at time t (oC)
%
%   get value of rhob(t) for current t using blade worth curve for BOI
      speed = rate;  if zloc(2) < zloc(1), speed = -speed;  end
      z = zloc(1)+speed*(t-tstrt);  
      if speed > 0 
        if z > zloc(2), z = zloc(2);  end 
      else
        if z < zloc(2), z = zloc(2);  end 
      end
      rhob = bworth(z,boi,yr)-bworth(zloc(1),boi,yr);  rhob = rhob/100; % Dk/k
%
%   determine temperature feedbacks
      Tunits = 'oC';   % options for reactivity coeffs (opt_alfTf set via input)
      [alfTf,alfTc] = temp_coeff(Tc,Tunits,opt_alfTf);% reactivity coeffs (Dk/k/oC)
      rhoTf = alfTf*(Tf - Tfr);        % fuel temp feedback
      rhoTc = alfTc*(Tc - Tcr);        % coolant temp feedback
% 
%  determine xenon feedbacks
      [dci,yi,dcx,yx,sigax,denom_rhox,sigfeff,sigf2,flxfull] = xenon_data();
      rhoX = X*sigax/sigf2/denom_rhox;          
%
%   calc derivative of state to pass back to the ODE solver
      rhof = rhoTc+rhoTf+rhoX;     % feedback rho (Dk/k)
      RHO = rho0+rhob-rhof;        % total rho  (Dk/k)
      xp(1) = (1/Gt)*(RHO-Be)*P + lam*C + kappa/(Gt*nu)*Q;
      xp(2:7) = B'*P/Gt - lam'.*C;
      [Ufc,Ucc,Cm,Cw] = htcoeff_umlrr(P,Tin,mode);  % HT coeffs (W/C) & m*Cp (J/C)
 %     Ufc = Ufc*1000;  Ucc = Ucc*1000;   % convert to W/C
      xp(8) = P/Cm - Ufc*(Tf - Tc)/Cm;
      xp(9) = Ufc*(Tf - Tc)/Cw + Ucc*(Tin - Tc)/Cw;
      rp = P/1e6;                   % fraction of full power at time t
      flx = cfac*rp*flxfull;        % "corrected" thermal flux at time t
      xp(10) = yi*sigfeff*flx - dci*I;
      xp(11) = dci*I + yx*sigfeff*flx - (dcx+sigax*flx)*X;
%
%    end of function