%
%   XENON_DATA.M    Function to set the data needed to do 
%                      I-Xe simulations for the UMLRR
%
%   The data given in this file are used for performing I-Xe simulation for the 
%   UMLRR.  These data were originally embedded within the various xenon simulation 
%   codes, but it has been difficult to keep all these up to date.  Thus, I have 
%   decided to put the needed xenon and UMLRR-specific data into a separate file 
%   that can be easily kept updated and then simply call this file, as needed, 
%   within the various codes that do the I-Xe simulations.  This approach should be
%   more efficient than repeating this code in all the individual simulation
%   routines.   
%
%   File prepared by J. R. White, UMass-Lowell (March 2013)
%

      function [dci,yi,dcx,yx,sigax,denom_rhox,sigfeff,sigf2,flxfull] = xenon_data()
%
%   define I-Xe decay parameters (from Lamarsh)
      Thi = 6.7;                % half life for I-135 (hr)
      dci = log(2)/Thi/3600;    % decay constant for I-135 (1/sec)
      Thx = 9.2;                % half life for Xe-135 (hr)
      dcx = log(2)/Thx/3600;    % decay constant for Xe-135 (1/sec)
      yi = 0.0639;              % yield for U235 for I-135 (atoms/fission)
      yx = 0.00237;             % yield for U235 for Xe-135 (atoms/fission)
%
%   set xenon micro xsec (from Lamarsh)
      T = 293;  To = 293;       % absolute temperatures (K)  (assume room temp)
      ga = 1.158;               % non 1/v factor for Xe-135  (at T = 20 C = 293 K))
      sigaxo = 2.65e+6;         % 2200 m/s abs xsec for Xe-135  (barns)
      cm2pb = 1e-24;            % conversion factor (cm^2/barn)
      sigax = (sqrt(pi)/2)*ga*sigaxo*cm2pb*sqrt(To/T);   % thermal ave abs xs (cm^2)
%
%   data for UMLRR simulations (see results from umlrr_6factors.m)
      Pfull = 1e+6;                               % UMLRR full power level (W)
      kappa = 200*1.602e-13;                      % energy per fission (J = W-s)
      assydim = 7.7724;                           % assy square dimension (cm)
      fuelht = 59.69;                             % fuel heigth (cm)
      Vcore = 4*5*assydim^2*fuelht;               % core vol for 4x5 array (cm^3)
%       idata = menu('Select 2-g data set for the simulations:', ...
%                    ' Data generated in 1999 using SCALE 4.2  ', ...
%                    ' Data generated in 2010 using SCALE 6.0  ');
      idata = 2;   % default to the 2010 data
      if idata == 1     % ***  1999 data  ***
        nu = 2.434; p = 0.9272; epp = 1.0541;     % nu & factors of 4-factor formula
        PF = 0.6737; PT = 0.9690;                 % non-leakage probabilities
        sigf1 = 1.017e-3; sigf2 = 5.046e-2;       % macro fission xsecs (1/cm)
        ratio = 2.6368;                           % fast to thermal flux ratio
      else              % ***  2010 data  ***
        nu = 2.434; p = 0.8794; epp = 1.0674;     % nu & factors of 4-factor formula
        PF = 0.6652; PT = 0.9691;                 % non-leakage probabilities
        sigf1 = 1.214e-3; sigf2 = 5.036e-2;       % macro fission xsecs (1/cm)
        ratio = 2.7528;                           % fast to thermal flux ratio
      end
      denom_rhox = nu*p*epp*PF*PT;                % denominator of reactivity eqn.
      sigfeff = sigf1*ratio+sigf2;                % effective fiss xs (1/cm)
      flxfull = Pfull/(kappa*sigfeff*Vcore);      % 1 MW ave thm flux (neuts/cm^2-s)      
%
%   end of function
